from .base_object import BaseObject
from .rectangle import BaseRectangle
from .collectible import BaseCollectible
from .trigger import BaseTrigger
from .obstacle import BaseObstacle
from .layer import BaseLayer