
import numpy as np

def make_ball(color1 = (255, 127, 39),color2 = (255, 201, 14),transparency = (200, 191, 231)):
    return np.array(   
        [[transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color2,
        color2,
        color2,
        color2,
        color2,
        color2,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        color1,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency]]
    )